from django.shortcuts import render
from django.http import HttpResponse
from django.views import View
from django.views.generic.detail import DetailView
from django.views.generic.edit import CreateView
from django.views.generic.edit import UpdateView
from django.views.generic.list import ListView

from .models import ForumPost, Reply 

def index(request):
    return_string = "<br>"
    for reply in Reply.objects.all():
        return_string += '{} by {} posted {}, {}: <br> {} <br> Reply by {} posted {}, {}: <br> {}'.format(
            reply.forum_post.title, reply.forum_post.author, reply.forum_post.pub_datetime.strftime("%m/%d/%Y"), reply.forum_post.pub_datetime.strftime("%I:%M %p"), reply.forum_post.body, 
            reply.author, reply.pub_datetime.strftime("%m/%d/%Y"), reply.pub_datetime.strftime("%I:%M %p"), reply.body
            )
        return_string += "<br><br>"
        html_string = "<html><head> Widget's Forum <br><br> Forum Posts: </head><body> {} </body><html>".format(return_string)
    
    return HttpResponse(html_string)

def forum(request):
    posts = ForumPost.objects.all()
    context = {'posts': posts}
    return render(request, 'forum/forum.html', context)

class ForumListView(ListView):
    model = ForumPost
    template_name = 'forum/forum.html'
    context_object_name = 'posts'
    ordering = ['-pub_datetime']  # sort by newest to oldest

class ForumDetailView(DetailView):
    model = ForumPost
    template_name = 'forum/forumpost-details.html'
    context_object_name = 'post'

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context['replies'] = self.object.replies.all()
        return context

class AddForumPostView(CreateView):
    model = ForumPost
    fields = ['title', 'body', 'author']
    template_name = 'forum/forumpost-add.html'

class EditForumPostView(UpdateView):
    model = ForumPost
    fields = ['title', 'body', 'author']
    template_name = 'forum/forumpost-edit.html'