from django.db import models
from django.urls import reverse
from Assignments.models import Course


class Location(models.Model):
    MODE_CHOICES = (
        ('onsite', 'onsite'),
        ('online', 'online'),
        ('hybrid', 'hybrid'),
    )
    mode = models.CharField(max_length=6, choices=MODE_CHOICES)
    venue = models.TextField(max_length=200, default='')

    def __str__(self):
        return '{}, {} mode'.format(self.venue, self.mode)

    def get_absolute_url(self):
        return reverse('location_detail', args=[str(self.venue)])
    

class Event(models.Model):
    activity = models.TextField(max_length=1000, default='')
    target_datetime= models.DateTimeField()
    estimated_hours = models.FloatField()
    location = models.ForeignKey(
        Location,
        on_delete=models.PROTECT,
        related_name='course_name'
        )
    course = models.ForeignKey(
        Course,
        on_delete=models.PROTECT,
        related_name='course_name'
        )

    def __str__(self):
        return '{}'.format(self.activity)

    def get_absolute_url(self):
        return reverse('widgetcalendar:event-detail', kwargs={'pk': self.pk})

    def get_edit_url(self):
        return reverse('widgetcalendar:event-edit', kwargs={'pk' : self.pk} )